@@ -1,3 +1,18 @@
+# Copyright Contributors to the Rez project
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 from rez.utils.resources import ResourcePool, ResourceHandle
 from rez.utils.data_utils import cached_property
 from rez.plugin_managers import plugin_manager
@@ -250,6 +265,35 @@ class PackageRepository(object):
         """
         raise NotImplementedError
 
+    def remove_package(self, pkg_name, pkg_version):
+        """Remove a package.
+
+        Note that this should work even if the specified package is currently
+        ignored.
+
+        Args:
+            pkg_name (str): Package name
+            pkg_version(`Version`): Package version
+
+        Returns:
+            bool: True if the package was removed, False if it wasn't found.
+        """
+        raise NotImplementedError
+
+    def remove_ignored_since(self, days, dry_run=False, verbose=False):
+        """Remove packages ignored for >= specified number of days.
+
+        Args:
+            days (int): Remove packages ignored >= this many days
+            dry_run: Dry run mode
+            verbose (bool): Verbose mode
+
+        Returns:
+            int: Number of packages removed. In dry-run mode, returns the
+            number of packages that _would_ be removed.
+        """
+        raise NotImplementedError
+
     def pre_variant_install(self, variant_resource):
         """Called before a variant is installed.
 
@@ -601,19 +645,3 @@ class PackageRepositoryManager(object):
 
 # singleton
 package_repository_manager = PackageRepositoryManager()
-
-
-# Copyright 2013-2016 Allan Johns.
-#
-# This library is free software: you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation, either
-# version 3 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library.  If not, see <http://www.gnu.org/licenses/>.
